context("summarizeFeatureValues")

test_that("summarizeFeatureValues", {
  s = summarizeFeatureValues(testscenario1, "instance")
})
